﻿using System;
using System.Linq;
using System.Collections.ObjectModel;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;

using SmartX;
using INT63DC_2C.Forms;

namespace INT63DC_2C.Controls
{
    public partial class ControlCalibration16 : UserControl
    {
        #region Field
        private FormCalibration m_ParentForm;

        private Color NormalColor = Color.Black;
        private Color FinishColor = Color.Blue;

        private Collection<SmartButton> CollectionButtonLane;
        private Collection<SmartLabel> CollectionLabelWeight;
        private Collection<SmartLabel> CollectionLabelADC;
        private Collection<SmartLabel> CollectionLabelConstant;
        #endregion

        #region Constructor
        public ControlCalibration16(FormCalibration parent)
        {
            InitializeComponent();

            this.ParentForm = parent;

            this.CreateCollection();
            this.InitilizeControls();
            this.InitializeDesign();
            this.DisplayRefresh();
        }
        #endregion

        #region Property
        public FormCalibration ParentForm
        {
            get { return this.m_ParentForm; }
            private set { this.m_ParentForm = value; }
        }
        private int EquipmentColumns { get { return this.ParentForm.ParentForm.SystemConfig.EquipmentColumns; } }
        #endregion

        #region Method
        private void CreateCollection()
        {
            this.CollectionButtonLane = new Collection<SmartButton>();
            this.CollectionLabelWeight = new Collection<SmartLabel>();
            this.CollectionLabelADC = new Collection<SmartLabel>();
            this.CollectionLabelConstant = new Collection<SmartLabel>();

            for (int i = 1; i <= this.EquipmentColumns; i++)
            {
                this.CollectionButtonLane.Add(FindByNameUtil.SmartButton("buttonLane" + i, this));
                this.CollectionLabelWeight.Add(FindByNameUtil.SmartLabel("labelWeight" + i, this));
                this.CollectionLabelADC.Add(FindByNameUtil.SmartLabel("labelADC" + i, this));
                this.CollectionLabelConstant.Add(FindByNameUtil.SmartLabel("labelConstant" + i, this));
            }
        }
        private void InitilizeControls()
        {
            for (int i = 0; i < this.ParentForm.ParentForm.SystemConfig.EquipmentColumns; i++)
            {
                this.CollectionLabelWeight[i].Text = "0.0";
                this.CollectionLabelADC[i].Text = "0.0";
                this.CollectionLabelConstant[i].Text = "0.0";
            }
        }
        private void InitializeDesign()
        {
            
        }

        public void DisplayRefresh()
        {
            if (this.CollectionButtonLane == null || this.CollectionButtonLane.Count == 0)
                return;

            for (int i = 0; i < this.CollectionButtonLane.Count; i++)
            {
                this.CollectionButtonLane[i].ButtonUp();
            }
        }

        public void CalibrationBalance()
        {
            // Help
            this.ParentForm.UpdateDisplayHelpBalance();

            foreach (SmartButton bt in this.CollectionButtonLane)
            {
                if (bt.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN)
                    this.ParentForm.ParentForm.TransferData(CommunicationCommand.CalibrationBalance, bt.Tag.ToString());
            }

            this.ParentForm.CalibrationButtonEnable(false, false, true);
        }
        public void CalibrationStart()
        {
            // Help
            this.ParentForm.UpdateDisplayHelpStart();

            foreach (SmartButton bt in this.CollectionButtonLane)
            {
                if (bt.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN)
                    this.ParentForm.ParentForm.TransferData(CommunicationCommand.CalibrationStart, bt.Tag.ToString());

                bt.Enabled = false;
            }

            this.ParentForm.CalibrationButtonEnable(false, false, false);
        }
        public void CalibrationCancel()
        {
            // Help
            this.ParentForm.UpdateDisplayHelpCancel();

            foreach (SmartButton bt in this.CollectionButtonLane)
            {
                if (bt.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN)
                    this.ParentForm.ParentForm.TransferData(CommunicationCommand.CalibrationCancel, bt.Tag.ToString());

                bt.Enabled = true;
            }

            this.ParentForm.CalibrationButtonEnable(true, false, false);
        }

        public void UpdateConfiguration(DataStore.EquipmentStatus status, CalibrationItem config)
        {
            string value = "";

            value = Helper.StringToDecimalPlaces(config.Constant1.Trim(), 6);
            if (this.labelConstant1.Text != value)
                this.labelConstant1.Text = value;

            value = Helper.StringToDecimalPlaces(config.Constant2.Trim(), 6);
            if (this.labelConstant2.Text != value)
                this.labelConstant2.Text = value;

            value = Helper.StringToDecimalPlaces(config.Constant3.Trim(), 6);
            if (this.labelConstant3.Text != value)
                this.labelConstant3.Text = value;

            value = Helper.StringToDecimalPlaces(config.Constant4.Trim(), 6);
            if (this.labelConstant4.Text != value)
                this.labelConstant4.Text = value;

            value = Helper.StringToDecimalPlaces(config.Constant5.Trim(), 6);
            if (this.labelConstant5.Text != value)
                this.labelConstant5.Text = value;

            value = Helper.StringToDecimalPlaces(config.Constant6.Trim(), 6);
            if (this.labelConstant6.Text != value)
                this.labelConstant6.Text = value;

            value = Helper.StringToDecimalPlaces(config.Constant7.Trim(), 6);
            if (this.labelConstant7.Text != value)
                this.labelConstant7.Text = value;

            value = Helper.StringToDecimalPlaces(config.Constant8.Trim(), 6);
            if (this.labelConstant8.Text != value)
                this.labelConstant8.Text = value;

            value = Helper.StringToDecimalPlaces(config.Constant9.Trim(), 6);
            if (this.labelConstant9.Text != value)
                this.labelConstant9.Text = value;

            value = Helper.StringToDecimalPlaces(config.Constant10.Trim(), 6);
            if (this.labelConstant10.Text != value)
                this.labelConstant10.Text = value;

            value = Helper.StringToDecimalPlaces(config.Constant11.Trim(), 6);
            if (this.labelConstant11.Text != value)
                this.labelConstant11.Text = value;

            value = Helper.StringToDecimalPlaces(config.Constant12.Trim(), 6);
            if (this.labelConstant12.Text != value)
                this.labelConstant12.Text = value;

            value = Helper.StringToDecimalPlaces(config.Constant13.Trim(), 6);
            if (this.labelConstant13.Text != value)
                this.labelConstant13.Text = value;

            value = Helper.StringToDecimalPlaces(config.Constant14.Trim(), 6);
            if (this.labelConstant14.Text != value)
                this.labelConstant14.Text = value;

            value = Helper.StringToDecimalPlaces(config.Constant15.Trim(), 6);
            if (this.labelConstant15.Text != value)
                this.labelConstant15.Text = value;

            value = Helper.StringToDecimalPlaces(config.Constant16.Trim(), 6);
            if (this.labelConstant16.Text != value)
                this.labelConstant16.Text = value;
        }
        public void UpdateWeightDisplay(DataStore.EquipmentStatus status, Collection<WeightData> weights)
        {
            if (this.CollectionLabelWeight == null || weights.Count < this.CollectionLabelWeight.Count || status == DataStore.EquipmentStatus.Start)
                return;

            for (int i = 0; i < weights.Count; i++)
            {
                if (this.CollectionButtonLane[i].ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN)
                {
                    this.UpdateLabelWeight(this.CollectionLabelWeight[i], this.CollectionLabelADC[i], weights[i], true);
                }
                else
                {
                    this.UpdateLabelWeight(this.CollectionLabelWeight[i], this.CollectionLabelADC[i], weights[i], false);
                }
            }
        }
        private void UpdateLabelWeight(SmartLabel labelWeight, SmartLabel labelADC, WeightData weightData, bool rbChecked)
        {
            switch (weightData.Status)
            {
                case DataStore.WeightStatus.CalNomal:
                    labelWeight.Text = Helper.DoubleToString(weightData.Weight, this.ParentForm.ParentForm.SystemConfig.DecimalPlaces);
                    labelWeight.ForeColor = this.NormalColor;
                    labelADC.Text = weightData.ADCValue;
                    break;
                case DataStore.WeightStatus.CalStandby:
                    if (rbChecked == true)
                    {
                        // 분동중량 표시
                        labelWeight.Text = string.Format("-{0}", this.ParentForm.labelBalanceWeight.Text);
                        labelWeight.ForeColor = this.NormalColor;
                        labelADC.Text = weightData.ADCValue;

                        // Help
                        this.ParentForm.UpdateDisplayHelpCalStandby();

                        this.ParentForm.CalibrationButtonEnable(false, true, true);
                    }
                    break;
                case DataStore.WeightStatus.CalBalans:
                    if (rbChecked == true)
                    {
                        // 분동중량표시
                        labelWeight.Text = string.Format("-{0}", this.ParentForm.labelBalanceWeight.Text);
                        labelWeight.ForeColor = this.NormalColor;
                        labelADC.Text = weightData.ADCValue;
                        this.ParentForm.CalibrationButtonEnable(false, false, true);
                    }
                    break;
                case DataStore.WeightStatus.CalFinish:
                    if (rbChecked == true)
                    {
                        // Help
                        this.ParentForm.UpdateDisplayHelpCalFinish();

                        this.ParentForm.CalibrationButtonEnable(true, false, false);
                        foreach (SmartX.SmartButton bt in this.CollectionButtonLane)
                            bt.Enabled = true;
                    }
                    labelWeight.Text = Helper.DoubleToString(weightData.Weight, this.ParentForm.ParentForm.SystemConfig.DecimalPlaces);
                    labelWeight.ForeColor = this.FinishColor;
                    labelADC.Text = weightData.ADCValue;
                    break;
                case DataStore.WeightStatus.CalError:
                    if (rbChecked == true)
                    {
                        // Help
                        this.ParentForm.UpdateDisplayHelpCalError();

                        this.ParentForm.CalibrationButtonEnable(true, false, false);
                        foreach (SmartX.SmartButton bt in this.CollectionButtonLane)
                            bt.Enabled = true;
                    }
                    labelWeight.Text = Helper.DoubleToString(weightData.Weight, this.ParentForm.ParentForm.SystemConfig.DecimalPlaces);
                    labelWeight.ForeColor = this.NormalColor;
                    labelADC.Text = weightData.ADCValue;
                    break;
                default:
                    break;
            }
        }
        #endregion

        #region Event Handler
        private void buttonLane_Click(object sender, EventArgs e)
        {
            SmartButton bt = sender as SmartButton;

            if (bt == null)
                return;

            // Help
            this.ParentForm.UpdateDisplayHelpInit();

            this.ParentForm.CalibrationButtonEnable(true, false, false);
        }
        #endregion
    }
}
