﻿using System;
using System.Linq;
using System.Collections.ObjectModel;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;

using SmartX;
using INT63DC_2C.Forms;

namespace INT63DC_2C.Controls
{
    public partial class ControlCalibration3 : UserControl
    {
        #region Field
        private FormCalibration m_ParentForm;

        private Color NormalColor = Color.Black;
        private Color FinishColor = Color.Blue;

        private Collection<SmartButton> CollectionButtonLine;
        private Collection<SmartLabel> CollectionLabelWeight;
        private Collection<SmartLabel> CollectionLabelADC;
        private Collection<SmartLabel> CollectionLabelConstant;
        #endregion

        #region Constructor
        public ControlCalibration3(FormCalibration parent)
        {
            InitializeComponent();

            this.ParentForm = parent;

            this.CreateCollection();
            this.InitilizeControls();
            this.InitializeDesign();
            this.DisplayRefresh();
        }
        #endregion

        #region Property
        public FormCalibration ParentForm
        {
            get { return this.m_ParentForm; }
            private set { this.m_ParentForm = value; }
        }
        #endregion

        #region Method
        private void CreateCollection()
        {
            this.CollectionButtonLine = new Collection<SmartButton>();
            this.CollectionLabelWeight = new Collection<SmartLabel>();
            this.CollectionLabelADC = new Collection<SmartLabel>();
            this.CollectionLabelConstant = new Collection<SmartLabel>();

            this.CollectionButtonLine.Clear();
            this.CollectionLabelWeight.Clear();
            this.CollectionLabelADC.Clear();
            this.CollectionLabelConstant.Clear();

            this.CollectionButtonLine.Add(this.buttonLane1);
            this.CollectionButtonLine.Add(this.buttonLane2);
            this.CollectionButtonLine.Add(this.buttonLane3);

            this.CollectionLabelWeight.Add(this.labelWeight1);
            this.CollectionLabelWeight.Add(this.labelWeight2);
            this.CollectionLabelWeight.Add(this.labelWeight3);

            this.CollectionLabelADC.Add(this.labelADC1);
            this.CollectionLabelADC.Add(this.labelADC2);
            this.CollectionLabelADC.Add(this.labelADC3);

            this.CollectionLabelConstant.Add(this.labelConstant1);
            this.CollectionLabelConstant.Add(this.labelConstant2);
            this.CollectionLabelConstant.Add(this.labelConstant3);
        }
        private void InitilizeControls()
        {
            for (int i = 0; i < this.ParentForm.ParentForm.SystemConfig.EquipmentColumns; i++)
            {
                this.CollectionLabelWeight[i].Text = "0.0";
                this.CollectionLabelADC[i].Text = "0.0";
                this.CollectionLabelConstant[i].Text = "0.0";
            }
        }
        private void InitializeDesign()
        {

        }

        public void DisplayRefresh()
        {
            if (this.CollectionButtonLine == null || this.CollectionButtonLine.Count == 0)
                return;

            for (int i = 0; i < this.CollectionButtonLine.Count; i++)
            {
                this.CollectionButtonLine[i].ButtonUp();
            }
        }

        public void CalibrationBalance()
        {
            // Help
            this.ParentForm.UpdateDisplayHelpBalance();

            foreach (SmartButton bt in this.CollectionButtonLine)
            {
                if (bt.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN)
                    this.ParentForm.ParentForm.TransferData(CommunicationCommand.CalibrationBalance, bt.Tag.ToString());
            }

            this.ParentForm.CalibrationButtonEnable(false, false, true);
        }
        public void CalibrationStart()
        {
            // Help
            this.ParentForm.UpdateDisplayHelpStart();

            foreach (SmartButton bt in this.CollectionButtonLine)
            {
                if (bt.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN)
                    this.ParentForm.ParentForm.TransferData(CommunicationCommand.CalibrationStart, bt.Tag.ToString());

                bt.Enabled = false;
            }

            this.ParentForm.CalibrationButtonEnable(false, false, false);
        }
        public void CalibrationCancel()
        {
            // Help
            this.ParentForm.UpdateDisplayHelpCancel();

            foreach (SmartButton bt in this.CollectionButtonLine)
            {
                if (bt.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN)
                    this.ParentForm.ParentForm.TransferData(CommunicationCommand.CalibrationCancel, bt.Tag.ToString());

                bt.Enabled = true;
            }

            this.ParentForm.CalibrationButtonEnable(true, false, false);
        }

        public void UpdateConfiguration(DataStore.EquipmentStatus status, CalibrationItem config)
        {
            string value = "";

            value = Helper.StringToDecimalPlaces(config.Constant1.Trim(), 6);
            if (this.labelConstant1.Text != value)
                this.labelConstant1.Text = value;

            value = Helper.StringToDecimalPlaces(config.Constant2.Trim(), 6);
            if (this.labelConstant2.Text != value)
                this.labelConstant2.Text = value;

            value = Helper.StringToDecimalPlaces(config.Constant3.Trim(), 6);
            if (this.labelConstant3.Text != value)
                this.labelConstant3.Text = value;
        }
        public void UpdateWeightDisplay(DataStore.EquipmentStatus status, Collection<WeightData> weights)
        {
            if (this.CollectionLabelWeight == null || weights.Count < this.CollectionLabelWeight.Count || status == DataStore.EquipmentStatus.Start)
                return;

            for (int i = 0; i < weights.Count; i++)
            {
                if (this.CollectionButtonLine[i].ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN)
                {
                    this.UpdateLabelWeight(this.CollectionLabelWeight[i], this.CollectionLabelADC[i], weights[i], true);
                }
                else
                {
                    this.UpdateLabelWeight(this.CollectionLabelWeight[i], this.CollectionLabelADC[i], weights[i], false);
                }
            }
        }
        private void UpdateLabelWeight(SmartLabel labelWeight, SmartLabel labelADC, WeightData weightData, bool rbChecked)
        {
            switch (weightData.Status)
            {
                case DataStore.WeightStatus.CalNomal:
                    labelWeight.Text = Helper.DoubleToString(weightData.Weight, this.ParentForm.ParentForm.SystemConfig.DecimalPlaces);
                    labelWeight.ForeColor = this.NormalColor;
                    labelADC.Text = weightData.ADCValue;
                    break;
                case DataStore.WeightStatus.CalStandby:
                    if (rbChecked == true)
                    {
                        // 분동중량 표시
                        labelWeight.Text = string.Format("-{0}", this.ParentForm.labelBalanceWeight.Text);
                        labelWeight.ForeColor = this.NormalColor;
                        labelADC.Text = weightData.ADCValue;

                        // Help
                        this.ParentForm.UpdateDisplayHelpCalStandby();

                        this.ParentForm.CalibrationButtonEnable(false, true, true);
                    }
                    break;
                case DataStore.WeightStatus.CalBalans:
                    if (rbChecked == true)
                    {
                        // 분동중량표시
                        labelWeight.Text = string.Format("-{0}", this.ParentForm.labelBalanceWeight.Text);
                        labelWeight.ForeColor = this.NormalColor;
                        labelADC.Text = weightData.ADCValue;
                        this.ParentForm.CalibrationButtonEnable(false, false, true);
                    }
                    break;
                case DataStore.WeightStatus.CalFinish:
                    if (rbChecked == true)
                    {
                        // Help
                        this.ParentForm.UpdateDisplayHelpCalFinish();

                        this.ParentForm.CalibrationButtonEnable(true, false, false);
                        foreach (SmartX.SmartButton bt in this.CollectionButtonLine)
                            bt.Enabled = true;
                    }
                    labelWeight.Text = Helper.DoubleToString(weightData.Weight, this.ParentForm.ParentForm.SystemConfig.DecimalPlaces);
                    labelWeight.ForeColor = this.FinishColor;
                    labelADC.Text = weightData.ADCValue;
                    break;
                case DataStore.WeightStatus.CalError:
                    if (rbChecked == true)
                    {
                        // Help
                        this.ParentForm.UpdateDisplayHelpCalError();

                        this.ParentForm.CalibrationButtonEnable(true, false, false);
                        foreach (SmartX.SmartButton bt in this.CollectionButtonLine)
                            bt.Enabled = true;
                    }
                    labelWeight.Text = Helper.DoubleToString(weightData.Weight, this.ParentForm.ParentForm.SystemConfig.DecimalPlaces);
                    labelWeight.ForeColor = this.NormalColor;
                    labelADC.Text = weightData.ADCValue;
                    break;
                default:
                    break;
            }
        }
        #endregion

        #region Event Handler
        private void buttonLane_Click(object sender, EventArgs e)
        {
            SmartButton bt = sender as SmartButton;

            if (bt == null)
                return;

            // Help
            this.ParentForm.UpdateDisplayHelpInit();

            this.ParentForm.CalibrationButtonEnable(true, false, false);
        }
        #endregion
    }
}
